@@ -1,6 +1,6 @@
 /*
  * AJD4JP
- * Copyright (c) 2011-2012  Akira Terasaki
+ * Copyright (c) 2011-2017  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に
  * 同意できる場合にのみ利用可能です。
  */
@@ -13,10 +13,10 @@ package ajd4jp;
  */
 public class Version {
 	private Version(){}
-	private static final String VERSION = "1.3.4.2015";
-	private static final String	SITE = "(http://ajd4jp.sourceforge.jp/)";
+	private static final String VERSION = "1.4.1.2017";
+	private static final String	SITE = "(http://ajd4jp.osdn.jp/)";
 	private static final String TITLE = "AJD4JP " + VERSION + SITE;
-	private static final String COPY = "Copyright 2011-2012 Akira Terasaki";
+	private static final String COPY = "Copyright 2011-2017 Akira Terasaki";
 
 	/**
 	 * バージョン番号の取得。
